window.Gleam.initSearch([{"doc":"gjwt","title":"gjwt","content":"# GJWT\n\n[![Package Version](https://img.shields.io/hexpm/v/gjwt)](https://hex.pm/packages/gjwt)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gjwt/)\n\n```sh\ngleam add gjwt\n```\n```gleam\nimport birl\nimport birl/duration\nimport gjwt.{add_claim, add_header, new, sign_off, verify, from_jwt}\nimport gjwt/claim.{expiration_time}\nimport gjwt/key.{from_string}\nimport gleam/dynamic\nimport gleam/io\n\npub fn main() {\n  let key = from_string(\n    // your key\n    &quot;1111111111111111111111111111111111111111111111111111111111111113&quot;,\n    // method to use\n    &quot;HS512&quot;,\n  )\n  let token = new()\n  |&gt; add_header(&quot;funky&quot;, dynamic.from(True))\n  |&gt; add_claim(#(&quot;test&quot;, dynamic.from(&quot;This is a test!&quot;)))\n  |&gt; add_claim(expiration_time(birl.add(birl.now(), duration.seconds(15))))\n    // convert to JWT\n  |&gt; sign_off(key)\n  io.debug(token) // Have a look at it\n  case verify(token, key) {\n    True -&gt; io.debug(&quot;Valid verified token!&quot;)\n    False -&gt; io.debug(&quot;Bad token&quot;) // you shouldn&#39;t get here in this example\n  }\n  // attempt to parse the token\n  case from_jwt(token, key) {\n    Ok(verified_jwt) -&gt; io.debug(verified_jwt)\n    Error(_) -&gt; io.debug(&quot;Bad token&quot;) // you shouldn&#39;t get here in this example\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gjwt&gt;.\n","url":"index.html"},{"doc":"gjwt/jsonify","title":"jsonify","content":"pub fn jsonify(dyn: Dynamic) -&gt; Json\n\nSynonyms:\ngjwt/jsonify.jsonify\ngjwt/jsonify jsonify","url":"gjwt/jsonify.html#jsonify"},{"doc":"gjwt/jsonify","title":"gjwt/jsonify","content":"","url":"gjwt/jsonify.html"},{"doc":"gjwt/header","title":"Header","content":"pub type Header {\n  Header(entries: HeaderEntries)\n}\n\nHeader(entries: HeaderEntries)\n\n\nSynonyms:\ngjwt/header.Header\ngjwt/header Header","url":"gjwt/header.html#Header"},{"doc":"gjwt/header","title":"HeaderEntries","content":"pub type HeaderEntries =\n  List(HeaderEntry)\n\n\nSynonyms:\ngjwt/header.HeaderEntries\ngjwt/header HeaderEntries","url":"gjwt/header.html#HeaderEntries"},{"doc":"gjwt/header","title":"HeaderEntry","content":"pub type HeaderEntry =\n  #(String, dynamic.Dynamic)\n\n\nSynonyms:\ngjwt/header.HeaderEntry\ngjwt/header HeaderEntry","url":"gjwt/header.html#HeaderEntry"},{"doc":"gjwt/header","title":"add_entry","content":"pub fn add_entry(\n  header: Header,\n  entry: #(String, Dynamic),\n) -&gt; Header\n\nSynonyms:\ngjwt/header.add_entry\ngjwt/header add_entry","url":"gjwt/header.html#add_entry"},{"doc":"gjwt/header","title":"get_entries","content":"pub fn get_entries(header: Header) -&gt; List(#(String, Dynamic))\n\nSynonyms:\ngjwt/header.get_entries\ngjwt/header get_entries","url":"gjwt/header.html#get_entries"},{"doc":"gjwt/header","title":"get_entry","content":"pub fn get_entry(\n  header: Header,\n  key: String,\n) -&gt; Result(#(String, Dynamic), Nil)\n\nSynonyms:\ngjwt/header.get_entry\ngjwt/header get_entry","url":"gjwt/header.html#get_entry"},{"doc":"gjwt/header","title":"new","content":"pub fn new() -&gt; Header\n\nSynonyms:\ngjwt/header.new\ngjwt/header new","url":"gjwt/header.html#new"},{"doc":"gjwt/header","title":"remove_entry","content":"pub fn remove_entry(header: Header, key: String) -&gt; Header\n\nSynonyms:\ngjwt/header.remove_entry\ngjwt/header remove_entry","url":"gjwt/header.html#remove_entry"},{"doc":"gjwt/header","title":"to_json","content":"pub fn to_json(header: Header) -&gt; Json\n\nSynonyms:\ngjwt/header.to_json\ngjwt/header to_json","url":"gjwt/header.html#to_json"},{"doc":"gjwt/header","title":"gjwt/header","content":"","url":"gjwt/header.html"},{"doc":"gjwt/key","title":"Key","content":"pub type Key {\n  Key(key: BitArray, algorithm: String, kty: String)\n}\n For kty see https://hexdocs.pm/jose/readme.html\nKey(key: BitArray, algorithm: String, kty: String)\n\n\nSynonyms:\ngjwt/key.Key\ngjwt/key Key","url":"gjwt/key.html#Key"},{"doc":"gjwt/key","title":"default_kty","content":"pub const default_kty: String\n\nSynonyms:\ngjwt/key.default_kty\ngjwt/key default_kty","url":"gjwt/key.html#default_kty"},{"doc":"gjwt/key","title":"from_string","content":"pub fn from_string(key: String, algorithm: String) -&gt; Key\n\nSynonyms:\ngjwt/key.from_string\ngjwt/key from_string","url":"gjwt/key.html#from_string"},{"doc":"gjwt/key","title":"gjwt/key","content":"","url":"gjwt/key.html"},{"doc":"gjwt/claim","title":"Claim","content":"pub type Claim =\n  #(String, dynamic.Dynamic)\n\n\nSynonyms:\ngjwt/claim.Claim\ngjwt/claim Claim","url":"gjwt/claim.html#Claim"},{"doc":"gjwt/claim","title":"Claims","content":"pub type Claims =\n  List(#(String, dynamic.Dynamic))\n\n\nSynonyms:\ngjwt/claim.Claims\ngjwt/claim Claims","url":"gjwt/claim.html#Claims"},{"doc":"gjwt/claim","title":"Error","content":"pub type Error {\n  NoClaim\n  ClaimDecode(errors: dynamic.DecodeErrors)\n}\n\nNoClaim\n\n\nClaimDecode(errors: dynamic.DecodeErrors)\n\n\nSynonyms:\ngjwt/claim.Error\ngjwt/claim Error","url":"gjwt/claim.html#Error"},{"doc":"gjwt/claim","title":"audience_key","content":"pub const audience_key: String\n\nSynonyms:\ngjwt/claim.audience_key\ngjwt/claim audience_key","url":"gjwt/claim.html#audience_key"},{"doc":"gjwt/claim","title":"expiration_time_key","content":"pub const expiration_time_key: String\n\nSynonyms:\ngjwt/claim.expiration_time_key\ngjwt/claim expiration_time_key","url":"gjwt/claim.html#expiration_time_key"},{"doc":"gjwt/claim","title":"issued_at_key","content":"pub const issued_at_key: String\n\nSynonyms:\ngjwt/claim.issued_at_key\ngjwt/claim issued_at_key","url":"gjwt/claim.html#issued_at_key"},{"doc":"gjwt/claim","title":"issuer_key","content":"pub const issuer_key: String\n\nSynonyms:\ngjwt/claim.issuer_key\ngjwt/claim issuer_key","url":"gjwt/claim.html#issuer_key"},{"doc":"gjwt/claim","title":"jwt_id_key","content":"pub const jwt_id_key: String\n\nSynonyms:\ngjwt/claim.jwt_id_key\ngjwt/claim jwt_id_key","url":"gjwt/claim.html#jwt_id_key"},{"doc":"gjwt/claim","title":"not_before_key","content":"pub const not_before_key: String\n\nSynonyms:\ngjwt/claim.not_before_key\ngjwt/claim not_before_key","url":"gjwt/claim.html#not_before_key"},{"doc":"gjwt/claim","title":"subject_key","content":"pub const subject_key: String\n\nSynonyms:\ngjwt/claim.subject_key\ngjwt/claim subject_key","url":"gjwt/claim.html#subject_key"},{"doc":"gjwt/claim","title":"add_claim","content":"pub fn add_claim(\n  claims: List(#(String, Dynamic)),\n  claim: #(String, Dynamic),\n) -&gt; List(#(String, Dynamic))\n\nSynonyms:\ngjwt/claim.add_claim\ngjwt/claim add_claim","url":"gjwt/claim.html#add_claim"},{"doc":"gjwt/claim","title":"audience","content":"pub fn audience(audience: List(String)) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.audience\ngjwt/claim audience","url":"gjwt/claim.html#audience"},{"doc":"gjwt/claim","title":"expiration_time","content":"pub fn expiration_time(\n  expiration_time: Time,\n) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.expiration_time\ngjwt/claim expiration_time","url":"gjwt/claim.html#expiration_time"},{"doc":"gjwt/claim","title":"get_audience","content":"pub fn get_audience(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(List(String), Error)\n\nSynonyms:\ngjwt/claim.get_audience\ngjwt/claim get_audience","url":"gjwt/claim.html#get_audience"},{"doc":"gjwt/claim","title":"get_claim","content":"pub fn get_claim(\n  claims: List(#(String, Dynamic)),\n  key: String,\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, Error)\n\nSynonyms:\ngjwt/claim.get_claim\ngjwt/claim get_claim","url":"gjwt/claim.html#get_claim"},{"doc":"gjwt/claim","title":"get_expiration_time","content":"pub fn get_expiration_time(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(Time, Error)\n\nSynonyms:\ngjwt/claim.get_expiration_time\ngjwt/claim get_expiration_time","url":"gjwt/claim.html#get_expiration_time"},{"doc":"gjwt/claim","title":"get_issued_at","content":"pub fn get_issued_at(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(Time, Error)\n\nSynonyms:\ngjwt/claim.get_issued_at\ngjwt/claim get_issued_at","url":"gjwt/claim.html#get_issued_at"},{"doc":"gjwt/claim","title":"get_issuer","content":"pub fn get_issuer(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(String, Error)\n\nSynonyms:\ngjwt/claim.get_issuer\ngjwt/claim get_issuer","url":"gjwt/claim.html#get_issuer"},{"doc":"gjwt/claim","title":"get_jwt_id","content":"pub fn get_jwt_id(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(String, Error)\n\nSynonyms:\ngjwt/claim.get_jwt_id\ngjwt/claim get_jwt_id","url":"gjwt/claim.html#get_jwt_id"},{"doc":"gjwt/claim","title":"get_not_before","content":"pub fn get_not_before(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(Time, Error)\n\nSynonyms:\ngjwt/claim.get_not_before\ngjwt/claim get_not_before","url":"gjwt/claim.html#get_not_before"},{"doc":"gjwt/claim","title":"get_subject","content":"pub fn get_subject(\n  claims: List(#(String, Dynamic)),\n) -&gt; Result(String, Error)\n\nSynonyms:\ngjwt/claim.get_subject\ngjwt/claim get_subject","url":"gjwt/claim.html#get_subject"},{"doc":"gjwt/claim","title":"issued_at","content":"pub fn issued_at(issued_at: Time) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.issued_at\ngjwt/claim issued_at","url":"gjwt/claim.html#issued_at"},{"doc":"gjwt/claim","title":"issuer","content":"pub fn issuer(issuer: String) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.issuer\ngjwt/claim issuer","url":"gjwt/claim.html#issuer"},{"doc":"gjwt/claim","title":"jwt_id","content":"pub fn jwt_id(jwt_id: String) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.jwt_id\ngjwt/claim jwt_id","url":"gjwt/claim.html#jwt_id"},{"doc":"gjwt/claim","title":"not_before","content":"pub fn not_before(not_before: Time) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.not_before\ngjwt/claim not_before","url":"gjwt/claim.html#not_before"},{"doc":"gjwt/claim","title":"remove_claim","content":"pub fn remove_claim(\n  claims: List(#(String, Dynamic)),\n  key: String,\n) -&gt; List(#(String, Dynamic))\n\nSynonyms:\ngjwt/claim.remove_claim\ngjwt/claim remove_claim","url":"gjwt/claim.html#remove_claim"},{"doc":"gjwt/claim","title":"set_claim","content":"pub fn set_claim(\n  claims: List(#(String, Dynamic)),\n  key: String,\n  value: Dynamic,\n) -&gt; List(#(String, Dynamic))\n\nSynonyms:\ngjwt/claim.set_claim\ngjwt/claim set_claim","url":"gjwt/claim.html#set_claim"},{"doc":"gjwt/claim","title":"subject","content":"pub fn subject(subject: String) -&gt; #(String, Dynamic)\n\nSynonyms:\ngjwt/claim.subject\ngjwt/claim subject","url":"gjwt/claim.html#subject"},{"doc":"gjwt/claim","title":"gjwt/claim","content":"","url":"gjwt/claim.html"},{"doc":"gjwt/payload","title":"Payload","content":"pub type Payload {\n  Payload(claims: claim.Claims)\n}\n\nPayload(claims: claim.Claims)\n\n\nSynonyms:\ngjwt/payload.Payload\ngjwt/payload Payload","url":"gjwt/payload.html#Payload"},{"doc":"gjwt/payload","title":"add_claim","content":"pub fn add_claim(\n  payload: Payload,\n  claim: #(String, Dynamic),\n) -&gt; Payload\n\nSynonyms:\ngjwt/payload.add_claim\ngjwt/payload add_claim","url":"gjwt/payload.html#add_claim"},{"doc":"gjwt/payload","title":"get_claim","content":"pub fn get_claim(\n  payload: Payload,\n  key: String,\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, Error)\n\nSynonyms:\ngjwt/payload.get_claim\ngjwt/payload get_claim","url":"gjwt/payload.html#get_claim"},{"doc":"gjwt/payload","title":"new","content":"pub fn new() -&gt; Payload\n\nSynonyms:\ngjwt/payload.new\ngjwt/payload new","url":"gjwt/payload.html#new"},{"doc":"gjwt/payload","title":"remove_claim","content":"pub fn remove_claim(payload: Payload, key: String) -&gt; Payload\n\nSynonyms:\ngjwt/payload.remove_claim\ngjwt/payload remove_claim","url":"gjwt/payload.html#remove_claim"},{"doc":"gjwt/payload","title":"set_claim","content":"pub fn set_claim(\n  payload: Payload,\n  key: String,\n  value: Dynamic,\n) -&gt; Payload\n\nSynonyms:\ngjwt/payload.set_claim\ngjwt/payload set_claim","url":"gjwt/payload.html#set_claim"},{"doc":"gjwt/payload","title":"to_json","content":"pub fn to_json(payload: Payload) -&gt; Json\n\nSynonyms:\ngjwt/payload.to_json\ngjwt/payload to_json","url":"gjwt/payload.html#to_json"},{"doc":"gjwt/payload","title":"gjwt/payload","content":"","url":"gjwt/payload.html"},{"doc":"gjwt","title":"JWT","content":"pub type JWT =\n  #(header.Header, payload.Payload)\n\n\nSynonyms:\ngjwt.JWT\ngjwt JWT","url":"gjwt.html#JWT"},{"doc":"gjwt","title":"add_claim","content":"pub fn add_claim(\n  jwt: #(Header, Payload),\n  claim: #(String, Dynamic),\n) -&gt; #(Header, Payload)\n\nSynonyms:\ngjwt.add_claim\ngjwt add_claim","url":"gjwt.html#add_claim"},{"doc":"gjwt","title":"add_header","content":"pub fn add_header(\n  jwt: #(Header, Payload),\n  key: String,\n  value: Dynamic,\n) -&gt; #(Header, Payload)\n\nSynonyms:\ngjwt.add_header\ngjwt add_header","url":"gjwt.html#add_header"},{"doc":"gjwt","title":"from_jwt","content":"pub fn from_jwt(\n  jwt_as_string: String,\n  key: Key,\n) -&gt; Result(#(Header, Payload), Nil)\n\nSynonyms:\ngjwt.from_jwt\ngjwt from_jwt","url":"gjwt.html#from_jwt"},{"doc":"gjwt","title":"new","content":"pub fn new() -&gt; #(Header, Payload)\n\nSynonyms:\ngjwt.new\ngjwt new","url":"gjwt.html#new"},{"doc":"gjwt","title":"sign_off","content":"pub fn sign_off(jwt: #(Header, Payload), key: Key) -&gt; String\n\nSynonyms:\ngjwt.sign_off\ngjwt sign_off","url":"gjwt.html#sign_off"},{"doc":"gjwt","title":"verify","content":"pub fn verify(jwt_as_string: String, key: Key) -&gt; Bool\n\nSynonyms:\ngjwt.verify\ngjwt verify","url":"gjwt.html#verify"},{"doc":"gjwt","title":"gjwt","content":"","url":"gjwt.html"}]);